package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.TmstrainLoadingResultMapper;
import com.steerinfo.dil.mapper.TmstrainWagonUnloadResultMapper;
import com.steerinfo.dil.model.TmstrainLoadingResult;
import com.steerinfo.dil.model.TmstrainWagonUnloadResult;
import com.steerinfo.dil.service.ITmstrainWagonUnloadResultService;
import com.steerinfo.dil.util.DataChange;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * TmstrainWagonUnloadResult服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-08-19 09:22
 * 类描述
 * 修订历史：
 * 日期：2021-08-19
 * 作者：generator
 * 参考：
 * 描述：TmstrainWagonUnloadResult服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "tmstrainWagonUnloadResultService")
public class TmstrainWagonUnloadResultServiceImpl implements ITmstrainWagonUnloadResultService {

    @Autowired
    private TmstrainWagonUnloadResultMapper tmstrainWagonUnloadResultMapper;

    @Autowired
    private TmstrainLoadingResultServiceImpl tmstrainLoadingResultService;

    /**
     * 查看所有卸车实绩
     * 1采购进口矿（万州港-达州站/万州港-老区轨道衡） 2采购进口矿（海港-老区轨道衡） 3采购国产矿  4内转
     * @param map
     * @return
     */
    @Override
    public List<Map<String, Object>> getTmstrainWagonUnLoad(Map<String, Object> map) {
        BigDecimal resultType = DataChange.dataToBigDecimal(map.get("resultType"));
        switch (resultType.intValue()){
            case 1:
            case 2:
            case 3:
                return tmstrainWagonUnloadResultMapper.getTmsWagonUnLoadInfo(map);
            case 4:
        }
        return null;
    }

    /**
     * 删除卸车实绩
     * @param unloadingId
     * @return
     */
    @Override
    public int deleteTmstrainWagonUnLoadResultByUnLoadingId(BigDecimal unloadingId) {
        TmstrainWagonUnloadResult tmstrainWagonUnloadResult = new TmstrainWagonUnloadResult();
        tmstrainWagonUnloadResult.setId(unloadingId);
        tmstrainWagonUnloadResult.setDeleted(new BigDecimal(1));
        return tmstrainWagonUnloadResultMapper.updateByPrimaryKeySelective(tmstrainWagonUnloadResult);
    }

    /**
     * 新增车皮卸车
     * 1采购进口矿（万州港-达州站/万州港-老区轨道衡） 2采购进口矿（海港-老区轨道衡） 3采购国产矿  4内转
     * @param tmstrainWagonUnloadResult
     * @return
     */
    public int insertTmstrainWagonUnLoadResult(TmstrainWagonUnloadResult tmstrainWagonUnloadResult){
        int i = 0;
        BigDecimal resultType = tmstrainWagonUnloadResult.getResultType();
        switch (resultType.intValue()){
            case 1:
            case 2:
            case 3:
                i = addTmstrainWagonLoadResult(tmstrainWagonUnloadResult);
                break;
            case 4:
                i = addTmstrainWagonLoadResultForConverted(tmstrainWagonUnloadResult);
        }
        return i;
    }

    /**
     * 采购进口矿新增卸车实绩
     * @param tmstrainWagonUnloadResult
     * @return
     */

    public int addTmstrainWagonLoadResult(TmstrainWagonUnloadResult tmstrainWagonUnloadResult) {
        //常规字段插入
        tmstrainWagonUnloadResult.setInsertUsername("admin");
        tmstrainWagonUnloadResult.setInsertTime(new Date());
        tmstrainWagonUnloadResult.setDeleted(new BigDecimal(0));
        List<Map<String, Object>> wagonNoMapList = tmstrainWagonUnloadResult.getWagonNoList();
        int count = 0;
        for (Map<String, Object> map : wagonNoMapList) {
            String resultWagonNo = (String) map.get("resultWagonNo");
            //通过装车车皮号得到并插入采购订单id
            BigDecimal purchaseOrderId = tmstrainWagonUnloadResultMapper.getPurchaseOrderId(resultWagonNo);
            tmstrainWagonUnloadResult.setPurchaseOrderRailPlanId(purchaseOrderId);
            //生成主键id
            tmstrainWagonUnloadResult.setUnloadingId(tmstrainWagonUnloadResultMapper.selectMaxId());
            tmstrainWagonUnloadResult.setResultWagonNo(resultWagonNo);
            count += tmstrainWagonUnloadResultMapper.insertSelective(tmstrainWagonUnloadResult);
            count += updateLoadingResult(map); //修改装车实绩为已卸货
        }
        return count;
    }


    /**
     * 修改卸车实绩
     * @param tmstrainWagonUnloadResult
     * @return
     */
    @Override
    public int updateTmstrainWagonUnLoadResult(TmstrainWagonUnloadResult tmstrainWagonUnloadResult) {
        tmstrainWagonUnloadResult.setUpdateTime(new Date());
        return tmstrainWagonUnloadResultMapper.updateByPrimaryKeySelective(tmstrainWagonUnloadResult);
    }

    /**
     * 修改装车实绩状态为已卸车
     * @param map
     * @return
     */
    public int updateLoadingResult(Map<String, Object> map){
        //添加一条卸货实绩 修改装车状态为已卸车 3
        TmstrainLoadingResult tmstrainLoadingResult = new TmstrainLoadingResult();
        tmstrainLoadingResult.setResultId(DataChange.dataToBigDecimal(map.get("resultId")));
        tmstrainLoadingResult.setDeleted(new BigDecimal(3));
        return tmstrainLoadingResultService.updateTmstrainLoadingResult(tmstrainLoadingResult);
    }

    /**
     * 查看火运实绩
     * @param map
     * @return
     */
    @Override
    public List<Map<String, Object>> getTmstrainResult(Map<String, Object> map) {
        return tmstrainWagonUnloadResultMapper.getTmstrainResult(map);
    }

    @Override
    public List<Map<String, Object>> getUnloadingPointName() {
        return tmstrainWagonUnloadResultMapper.getUnloadingPointName();
    }

    @Override
    public List<Map<String, Object>> getUnloadingRouteName() {
        return tmstrainWagonUnloadResultMapper.getUnloadingRouteName();
    }

    /**
     * 通过主键查询信息
     * @param unloadingId
     * @return
     */
    @Override
    public List<Map<String, Object>> getTmstrainWagonUnLoadResultByUnLoadingId(BigDecimal unloadingId) {
        return tmstrainWagonUnloadResultMapper.selectByUnLoadingId(unloadingId);
    }


    /**
     * 内转物流新增卸车实绩
     * @param tmstrainWagonUnloadResult
     * @return
     */
    public int addTmstrainWagonLoadResultForConverted(TmstrainWagonUnloadResult tmstrainWagonUnloadResult) {
        //生成主键id
        tmstrainWagonUnloadResult.setUnloadingId(tmstrainWagonUnloadResultMapper.selectMaxId());
        //通过装车车皮号得到并插入采购订单id
        BigDecimal planId = tmstrainWagonUnloadResultMapper.getPurchaseOrderId(tmstrainWagonUnloadResult.getResultWagonNo());
        tmstrainWagonUnloadResult.setPurchaseOrderRailPlanId(planId);
        //常规字段插入
        tmstrainWagonUnloadResult.setInsertUsername("admin");
        tmstrainWagonUnloadResult.setInsertTime(new Date());
        tmstrainWagonUnloadResult.setUpdateUsername("admin");
        tmstrainWagonUnloadResult.setUpdateTime(new Date());
        tmstrainWagonUnloadResult.setInsertUpdateRemark("无");
        tmstrainWagonUnloadResult.setDeleted(new BigDecimal(0));
        return tmstrainWagonUnloadResultMapper.insertSelective(tmstrainWagonUnloadResult);
    }

    @Override
    public List<Map<String, Object>> selectWagonUnLoadResult(Map<String, Object> map) {
        return tmstrainWagonUnloadResultMapper.selectWagonUnLoadResult(map);
    }


    /**
     * 内转物流展示火车卸货实绩
     * @param map
     * @return
     */
    @Override
    public List<Map<String, Object>> getTrainResult(Map<String, Object> map) {
        return tmstrainWagonUnloadResultMapper.getTrainResult(map);
    }

}
